@@ -623,21 +623,28 @@ static bool
 attribute_is_trust_value (const CK_ATTRIBUTE *attr)
 {
 	switch (attr->type) {
-	case CKA_TRUST_DIGITAL_SIGNATURE:
-	case CKA_TRUST_NON_REPUDIATION:
-	case CKA_TRUST_KEY_ENCIPHERMENT:
-	case CKA_TRUST_DATA_ENCIPHERMENT:
-	case CKA_TRUST_KEY_AGREEMENT:
-	case CKA_TRUST_KEY_CERT_SIGN:
-	case CKA_TRUST_CRL_SIGN:
+	case CKA_NSS_TRUST_DIGITAL_SIGNATURE:
+	case CKA_NSS_TRUST_NON_REPUDIATION:
+	case CKA_NSS_TRUST_KEY_ENCIPHERMENT:
+	case CKA_NSS_TRUST_DATA_ENCIPHERMENT:
+	case CKA_NSS_TRUST_KEY_AGREEMENT:
+	case CKA_NSS_TRUST_KEY_CERT_SIGN:
+	case CKA_NSS_TRUST_CRL_SIGN:
+	case CKA_NSS_TRUST_SERVER_AUTH:
+	case CKA_NSS_TRUST_CLIENT_AUTH:
+	case CKA_NSS_TRUST_CODE_SIGNING:
+	case CKA_NSS_TRUST_EMAIL_PROTECTION:
+	case CKA_NSS_TRUST_IPSEC_END_SYSTEM:
+	case CKA_NSS_TRUST_IPSEC_TUNNEL:
+	case CKA_NSS_TRUST_IPSEC_USER:
+	case CKA_NSS_TRUST_TIME_STAMPING:
 	case CKA_TRUST_SERVER_AUTH:
 	case CKA_TRUST_CLIENT_AUTH:
 	case CKA_TRUST_CODE_SIGNING:
 	case CKA_TRUST_EMAIL_PROTECTION:
-	case CKA_TRUST_IPSEC_END_SYSTEM:
-	case CKA_TRUST_IPSEC_TUNNEL:
-	case CKA_TRUST_IPSEC_USER:
+	case CKA_TRUST_IPSEC_IKE:
 	case CKA_TRUST_TIME_STAMPING:
+	case CKA_TRUST_OCSP_SIGNING:
 		break;
 	default:
 		return false;
@@ -727,6 +734,13 @@ attribute_is_sensitive (const CK_ATTRIBUTE *attr,
 	X (CKA_DEFAULT_CMS_ATTRIBUTES)
 	X (CKA_SUPPORTED_CMS_ATTRIBUTES)
 	X (CKA_ALLOWED_MECHANISMS)
+	X (CKA_TRUST_SERVER_AUTH)
+	X (CKA_TRUST_CLIENT_AUTH)
+	X (CKA_TRUST_CODE_SIGNING)
+	X (CKA_TRUST_EMAIL_PROTECTION)
+	X (CKA_TRUST_IPSEC_IKE)
+	X (CKA_TRUST_TIME_STAMPING)
+	X (CKA_TRUST_OCSP_SIGNING)
 	X (CKA_X_ASSERTION_TYPE)
 	X (CKA_X_CERTIFICATE_VALUE)
 	X (CKA_X_PURPOSE)
@@ -747,24 +761,24 @@ attribute_is_sensitive (const CK_ATTRIBUTE *attr,
 	X (CKA_NSS_PQG_H)
 	X (CKA_NSS_PQG_SEED_BITS)
 	X (CKA_NSS_MODULE_SPEC)
-	X (CKA_TRUST_DIGITAL_SIGNATURE)
-	X (CKA_TRUST_NON_REPUDIATION)
-	X (CKA_TRUST_KEY_ENCIPHERMENT)
-	X (CKA_TRUST_DATA_ENCIPHERMENT)
-	X (CKA_TRUST_KEY_AGREEMENT)
-	X (CKA_TRUST_KEY_CERT_SIGN)
-	X (CKA_TRUST_CRL_SIGN)
-	X (CKA_TRUST_SERVER_AUTH)
-	X (CKA_TRUST_CLIENT_AUTH)
-	X (CKA_TRUST_CODE_SIGNING)
-	X (CKA_TRUST_EMAIL_PROTECTION)
-	X (CKA_TRUST_IPSEC_END_SYSTEM)
-	X (CKA_TRUST_IPSEC_TUNNEL)
-	X (CKA_TRUST_IPSEC_USER)
-	X (CKA_TRUST_TIME_STAMPING)
-	X (CKA_TRUST_STEP_UP_APPROVED)
-	X (CKA_CERT_SHA1_HASH)
-	X (CKA_CERT_MD5_HASH)
+	X (CKA_NSS_TRUST_DIGITAL_SIGNATURE)
+	X (CKA_NSS_TRUST_NON_REPUDIATION)
+	X (CKA_NSS_TRUST_KEY_ENCIPHERMENT)
+	X (CKA_NSS_TRUST_DATA_ENCIPHERMENT)
+	X (CKA_NSS_TRUST_KEY_AGREEMENT)
+	X (CKA_NSS_TRUST_KEY_CERT_SIGN)
+	X (CKA_NSS_TRUST_CRL_SIGN)
+	X (CKA_NSS_TRUST_SERVER_AUTH)
+	X (CKA_NSS_TRUST_CLIENT_AUTH)
+	X (CKA_NSS_TRUST_CODE_SIGNING)
+	X (CKA_NSS_TRUST_EMAIL_PROTECTION)
+	X (CKA_NSS_TRUST_IPSEC_END_SYSTEM)
+	X (CKA_NSS_TRUST_IPSEC_TUNNEL)
+	X (CKA_NSS_TRUST_IPSEC_USER)
+	X (CKA_NSS_TRUST_TIME_STAMPING)
+	X (CKA_NSS_TRUST_STEP_UP_APPROVED)
+	X (CKA_NSS_CERT_SHA1_HASH)
+	X (CKA_NSS_CERT_MD5_HASH)
 	X (CKA_IBM_OPAQUE)
 	X (CKA_IBM_RESTRICTABLE)
 	X (CKA_IBM_NEVER_MODIFIABLE)
