@@ -183,6 +183,33 @@ const p11_constant p11_constant_types[] = {
 	CT (CKA_HSS_LMS_TYPES, "hss-lms-types")
 	CT (CKA_HSS_LMOTS_TYPES, "hss-lmots-types")
 	CT (CKA_HSS_KEYS_REMAINING, "hss-keys-remaining")
+	CT (CKA_PARAMETER_SET, "parameter-set")
+	CT (CKA_OBJECT_VALIDATION_FLAGS, "object-validation-flag")
+	CT (CKA_VALIDATION_TYPE, "validation-type")
+	CT (CKA_VALIDATION_VERSION, "validation-version")
+	CT (CKA_VALIDATION_LEVEL, "validation-level")
+	CT (CKA_VALIDATION_MODULE_ID, "validation-module-id")
+	CT (CKA_VALIDATION_FLAG, "validation-flag")
+	CT (CKA_VALIDATION_AUTHORITY_TYPE, "validation-authority-type")
+	CT (CKA_VALIDATION_COUNTRY, "validation-country")
+	CT (CKA_VALIDATION_CERTIFICATE_IDENTIFIER, "validation-certificate-identifier")
+	CT (CKA_VALIDATION_CERTIFICATE_URI, "validation-certificate-uri")
+	CT (CKA_VALIDATION_VENDOR_URI, "validation-vendor-uri")
+	CT (CKA_VALIDATION_PROFILE, "validation-profile")
+	CT (CKA_ENCAPSULATE_TEMPLATE, "encapsulate-template")
+	CT (CKA_DECAPSULATE_TEMPLATE, "decapsulate_template")
+	CT (CKA_TRUST_SERVER_AUTH, "trust-server-auth")
+	CT (CKA_TRUST_CLIENT_AUTH, "trust-client-auth")
+	CT (CKA_TRUST_CODE_SIGNING, "trust-code-signing")
+	CT (CKA_TRUST_EMAIL_PROTECTION, "trust-email-protection")
+	CT (CKA_TRUST_IPSEC_IKE, "trust-ipsec-ike")
+	CT (CKA_TRUST_TIME_STAMPING, "trust-time-stamping")
+	CT (CKA_TRUST_OCSP_SIGNING, "trust-ocsp-signing")
+	CT (CKA_ENCAPSULATE, "encapsulate")
+	CT (CKA_DECAPSULATE, "decapsulate")
+	CT (CKA_HASH_OF_CERTIFICATE, "hash-of-certificate")
+	CT (CKA_PUBLIC_CRC64_VALUE, "public-crc64-value")
+	CT (CKA_SEED, "seed")
 	CT (CKA_WRAP_TEMPLATE, "wrap-template")
 	CT (CKA_UNWRAP_TEMPLATE, "unwrap-template")
 	CT (CKA_DERIVE_TEMPLATE, "derive-template")
@@ -233,24 +260,24 @@ const p11_constant p11_constant_types[] = {
 	CT (CKA_NSS_MOZILLA_CA_POLICY, "nss-mozilla-ca-policy")
 	CT (CKA_NSS_SERVER_DISTRUST_AFTER, "nss-server-distrust-after")
 	CT (CKA_NSS_EMAIL_DISTRUST_AFTER, "nss-email-distrust-after")
-	CT (CKA_TRUST_DIGITAL_SIGNATURE, "trust-digital-signature")
-	CT (CKA_TRUST_NON_REPUDIATION, "trust-non-repudiation")
-	CT (CKA_TRUST_KEY_ENCIPHERMENT, "trust-key-encipherment")
-	CT (CKA_TRUST_DATA_ENCIPHERMENT, "trust-data-encipherment")
-	CT (CKA_TRUST_KEY_AGREEMENT, "trust-key-agreement")
-	CT (CKA_TRUST_KEY_CERT_SIGN, "trust-key-cert-sign")
-	CT (CKA_TRUST_CRL_SIGN, "trust-crl-sign")
-	CT (CKA_TRUST_SERVER_AUTH, "trust-server-auth")
-	CT (CKA_TRUST_CLIENT_AUTH, "trust-client-auth")
-	CT (CKA_TRUST_CODE_SIGNING, "trust-code-signing")
-	CT (CKA_TRUST_EMAIL_PROTECTION, "trust-email-protection")
-	CT (CKA_TRUST_IPSEC_END_SYSTEM, "trust-ipsec-end-system")
-	CT (CKA_TRUST_IPSEC_TUNNEL, "trust-ipsec-tunnel")
-	CT (CKA_TRUST_IPSEC_USER, "trust-ipsec-user")
-	CT (CKA_TRUST_TIME_STAMPING, "trust-time-stamping")
-	CT (CKA_TRUST_STEP_UP_APPROVED, "trust-step-up-approved")
-	CT (CKA_CERT_SHA1_HASH, "cert-sha1-hash")
-	CT (CKA_CERT_MD5_HASH, "cert-md5-hash")
+	CT (CKA_NSS_TRUST_DIGITAL_SIGNATURE, "nss-trust-digital-signature")
+	CT (CKA_NSS_TRUST_NON_REPUDIATION, "nss-trust-non-repudiation")
+	CT (CKA_NSS_TRUST_KEY_ENCIPHERMENT, "nss-trust-key-encipherment")
+	CT (CKA_NSS_TRUST_DATA_ENCIPHERMENT, "nss-trust-data-encipherment")
+	CT (CKA_NSS_TRUST_KEY_AGREEMENT, "nss-trust-key-agreement")
+	CT (CKA_NSS_TRUST_KEY_CERT_SIGN, "nss-trust-key-cert-sign")
+	CT (CKA_NSS_TRUST_CRL_SIGN, "nss-trust-crl-sign")
+	CT (CKA_NSS_TRUST_SERVER_AUTH, "nss-trust-server-auth")
+	CT (CKA_NSS_TRUST_CLIENT_AUTH, "nss-trust-client-auth")
+	CT (CKA_NSS_TRUST_CODE_SIGNING, "nss-trust-code-signing")
+	CT (CKA_NSS_TRUST_EMAIL_PROTECTION, "nss-trust-email-protection")
+	CT (CKA_NSS_TRUST_IPSEC_END_SYSTEM, "nss-trust-ipsec-end-system")
+	CT (CKA_NSS_TRUST_IPSEC_TUNNEL, "nss-trust-ipsec-tunnel")
+	CT (CKA_NSS_TRUST_IPSEC_USER, "nss-trust-ipsec-user")
+	CT (CKA_NSS_TRUST_TIME_STAMPING, "nss-trust-time-stamping")
+	CT (CKA_NSS_TRUST_STEP_UP_APPROVED, "nss-trust-step-up-approved")
+	CT (CKA_NSS_CERT_SHA1_HASH, "nss-cert-sha1-hash")
+	CT (CKA_NSS_CERT_MD5_HASH, "nss-cert-md5-hash")
 	CT (CKA_X_ASSERTION_TYPE, "x-assertion-type")
 	CT (CKA_X_CERTIFICATE_VALUE, "x-certificate-value")
 	CT (CKA_X_PURPOSE, "x-purpose")
@@ -270,6 +297,8 @@ const p11_constant p11_constant_classes[] = {
 	CT (CKO_DOMAIN_PARAMETERS, "domain-parameters")
 	CT (CKO_MECHANISM, "mechanism")
 	CT (CKO_PROFILE, "profile")
+	CT (CKO_VALIDATION, "validation")
+	CT (CKO_TRUST, "trust")
 	CT (CKO_NSS_CRL, "nss-crl")
 	CT (CKO_NSS_SMIME, "nss-smime")
 	CT (CKO_NSS_TRUST, "nss-trust")
@@ -337,7 +366,7 @@ const p11_constant p11_constant_keys[] = {
 	CT (CKK_SHA384_HMAC, "ckk-sha384-hmac")
 	CT (CKK_SHA512_HMAC, "ckk-sha512-hmac")
 	CT (CKK_SHA224_HMAC, "ckk-sha224-hmac")
-	CT (CKK_SEED, "seed")
+	CT (CKK_SEED, "ckk-seed")
 	CT (CKK_GOSTR3410, "ckk-gostr3410")
 	CT (CKK_GOSTR3411, "ckk-gostr3411")
 	CT (CKK_GOST28147, "ckk-gost28147")
@@ -361,6 +390,11 @@ const p11_constant p11_constant_keys[] = {
 	CT (CKK_SHA512_256_HMAC, "ckk-sha512-256-hmac")
 	CT (CKK_SHA512_T_HMAC, "ckk-sha512-t-hmac")
 	CT (CKK_HSS, "ckk-hss")
+	CT (CKK_XMSS, "ckk-xmss")
+	CT (CKK_XMSSMT, "ckk-xmssmt")
+	CT (CKK_ML_KEM, "ckk-ml-kem")
+	CT (CKK_ML_DSA, "ckk-ml-dsa")
+	CT (CKK_SLH_DSA, "ckk-slh-dsa")
 	CT (CKK_IBM_PQC_DILITHIUM, "ibm-dilithium")
 	CT (CKK_NSS_PKCS8, "nss-pkcs8")
 	{ CKA_INVALID },
@@ -496,6 +530,12 @@ const p11_constant p11_constant_returns[] = {
 	CT (CKR_TOKEN_RESOURCE_EXCEEDED, NULL)
 	CT (CKR_OPERATION_CANCEL_FAILED, NULL)
 	CT (CKR_KEY_EXHAUSTED, NULL)
+	CT (CKR_PENDING, NULL)
+	CT (CKR_SESSION_ASYNC_NOT_SUPPORTED, NULL)
+	CT (CKR_SEED_RANDOM_REQUIRED, NULL)
+	CT (CKR_OPERATION_NOT_VALIDATED, NULL)
+	CT (CKR_TOKEN_NOT_INITIALIZED, NULL)
+	CT (CKR_PARAMETER_SET_NOT_SUPPORTED, NULL)
 	{ CKA_INVALID },
 };
 
@@ -515,6 +555,7 @@ const p11_constant p11_constant_mechanisms[] = {
 	CT (CKM_SHA1_RSA_X9_31, "sha1-rsa-x9-31")
 	CT (CKM_RSA_PKCS_PSS, "rsa-pkcs-pss")
 	CT (CKM_SHA1_RSA_PKCS_PSS, "sha1-rsa-pkcs-pss")
+	CT (CKM_ML_KEM_KEY_PAIR_GEN, "ml-kem-key-pair-gen")
 	CT (CKM_DSA_KEY_PAIR_GEN, "dsa-key-pair-gen")
 	CT (CKM_DSA, NULL) /* "dsa" */
 	CT (CKM_DSA_SHA1, "dsa-sha1")
@@ -522,16 +563,43 @@ const p11_constant p11_constant_mechanisms[] = {
 	CT (CKM_DSA_SHA256, "dsa-sha256")
 	CT (CKM_DSA_SHA384, "dsa-sha384")
 	CT (CKM_DSA_SHA512, "dsa-sha512")
+	CT (CKM_ML_KEM, "ml-kem")
 	CT (CKM_DSA_SHA3_224, "dsa-sha3-224")
 	CT (CKM_DSA_SHA3_256, "dsa-sha3-256")
 	CT (CKM_DSA_SHA3_384, "dsa-sha3-384")
 	CT (CKM_DSA_SHA3_512, "dsa-sha3-512")
+	CT (CKM_ML_DSA_KEY_PAIR_GEN, "ml-dsa-key-pair-gen")
+	CT (CKM_ML_DSA, "ml-dsa")
+	CT (CKM_HASH_ML_DSA, "hash-ml-dsa")
 	CT (CKM_DH_PKCS_KEY_PAIR_GEN, "dh-pkcs-key-pair-gen")
 	CT (CKM_DH_PKCS_DERIVE, "dh-pkcs-derive")
+	CT (CKM_HASH_ML_DSA_SHA224, "hash-ml-dsa-sha224")
+	CT (CKM_HASH_ML_DSA_SHA256, "hash-ml-dsa-sha256")
+	CT (CKM_HASH_ML_DSA_SHA384, "hash-ml-dsa-sha384")
+	CT (CKM_HASH_ML_DSA_SHA512, "hash-ml-dsa-sha512")
+	CT (CKM_HASH_ML_DSA_SHA3_224, "hash-ml-dsa-sha3-224")
+	CT (CKM_HASH_ML_DSA_SHA3_256, "hash-ml-dsa-sha3-256")
+	CT (CKM_HASH_ML_DSA_SHA3_384, "hash-ml-dsa-sha3-384")
+	CT (CKM_HASH_ML_DSA_SHA3_512, "hash-ml-dsa-sha3-512")
+	CT (CKM_HASH_ML_DSA_SHAKE128, "hash-ml-dsa-shake128")
+	CT (CKM_HASH_ML_DSA_SHAKE256, "hash-ml-dsa-shake256")
+	CT (CKM_SLH_DSA_KEY_PAIR_GEN, "slh-dsa-key-pair-gen")
+	CT (CKM_SLH_DSA, "slh-dsa")
 	CT (CKM_X9_42_DH_KEY_PAIR_GEN, "x9-42-dh-key-pair-gen")
 	CT (CKM_X9_42_DH_DERIVE, "x9-42-dh-derive")
 	CT (CKM_X9_42_DH_HYBRID_DERIVE, "x9-42-dh-hybrid-derive")
 	CT (CKM_X9_42_MQV_DERIVE, "x9-42-mqv-derive")
+	CT (CKM_HASH_SLH_DSA, "hash-slh-dsa")
+	CT (CKM_HASH_SLH_DSA_SHA224, "hash-slh-dsa-sha224")
+	CT (CKM_HASH_SLH_DSA_SHA256, "hash-slh-dsa-sha256")
+	CT (CKM_HASH_SLH_DSA_SHA384, "hash-slh-dsa-sha384")
+	CT (CKM_HASH_SLH_DSA_SHA512, "hash-slh-dsa-sha512")
+	CT (CKM_HASH_SLH_DSA_SHA3_224, "hash-slh-dsa-sha3-224")
+	CT (CKM_HASH_SLH_DSA_SHA3_256, "hash-slh-dsa-sha3-256")
+	CT (CKM_HASH_SLH_DSA_SHA3_384, "hash-slh-dsa-sha3-384")
+	CT (CKM_HASH_SLH_DSA_SHA3_512, "hash-slh-dsa-sha3-512")
+	CT (CKM_HASH_SLH_DSA_SHAKE128, "hash-slh-dsa-shake128")
+	CT (CKM_HASH_SLH_DSA_SHAKE256, "hash-slh-dsa-shake256")
 	CT (CKM_SHA256_RSA_PKCS, "sha256-rsa-pkcs")
 	CT (CKM_SHA384_RSA_PKCS, "sha384-rsa-pkcs")
 	CT (CKM_SHA512_RSA_PKCS, "sha512-rsa-pkcs")
@@ -552,6 +620,8 @@ const p11_constant p11_constant_mechanisms[] = {
 	CT (CKM_SHA512_T_HMAC, "sha512-t-hmac")
 	CT (CKM_SHA512_T_HMAC_GENERAL, "sha512-t-hmac-general")
 	CT (CKM_SHA512_T_KEY_DERIVATION, "sha512-t-key-derivation")
+	CT (CKM_TLS12_EXTENDED_MASTER_KEY_DERIVE, "tls12-extended-master-key-derive")
+	CT (CKM_TLS12_EXTENDED_MASTER_KEY_DERIVE_DH, "tls12-extended-master-key-derive-dh")
 	CT (CKM_SHA3_256_RSA_PKCS, "sha3-256-rsa-pkcs")
 	CT (CKM_SHA3_384_RSA_PKCS, "sha3-384-rsa-pkcs")
 	CT (CKM_SHA3_512_RSA_PKCS, "sha3-512-rsa-pkcs")
@@ -941,6 +1011,13 @@ const p11_constant p11_constant_mechanisms[] = {
 	CT (CKM_IKE1_EXTENDED_DERIVE, "ike1-extended-derive")
 	CT (CKM_HSS_KEY_PAIR_GEN, "hss-key-pair-gen")
 	CT (CKM_HSS, "hss")
+	CT (CKM_XMSS_KEY_PAIR_GEN, "xmss-key-pair-gen")
+	CT (CKM_XMSSMT_KEY_PAIR_GEN, "xmssmt-key-pair-gen")
+	CT (CKM_XMSS, "xmss")
+	CT (CKM_XMSSMT, "xmssmt")
+	CT (CKM_ECDH_X_AES_KEY_WRAP, "ecdh-x-aes-key-wrap")
+	CT (CKM_ECDH_COF_AES_KEY_WRAP, "ecdh-cof-aes-key-wrap")
+	CT (CKM_PUB_KEY_FROM_PRIV_KEY, "pub-key-from-priv-key")
 	CT (CKM_IBM_SHA3_224, "ibm-sha3-224")
 	CT (CKM_IBM_SHA3_256, "ibm-sha3-256")
 	CT (CKM_IBM_SHA3_384, "ibm-sha3-384")
