@@ -71,12 +71,14 @@ test_initialize_finalize (void)
 	CK_RV rv;
 
 	rv = C_GetFunctionList (&proxy);
-	assert (rv == CKR_OK);
+	assert_num_eq (rv, CKR_OK);
+	assert_num_eq (proxy->version.major, CRYPTOKI_LEGACY_VERSION_MAJOR);
+	assert_num_eq (proxy->version.minor, CRYPTOKI_LEGACY_VERSION_MINOR);
 
 	assert (p11_proxy_module_check (proxy));
 
 	rv = proxy->C_Initialize (NULL);
-	assert (rv == CKR_OK);
+	assert_num_eq (rv, CKR_OK);
 
 	rv = proxy->C_Finalize (NULL);
 	assert_num_eq (rv, CKR_OK);
@@ -134,6 +136,7 @@ test_initialize_child (void)
 
 	count = 32;
 	rv = proxy->C_GetSlotList (CK_FALSE, slots, &count);
+	assert_num_eq (rv, CKR_OK);
 	assert_num_cmp (count, >=, 2);
 	last_slot = slots[count - 1];
 	last_count = count;
@@ -236,6 +239,7 @@ teardown (void *unused)
 #define ENABLED_PREFIX "enable-in: test-proxy-suffix, p11-kit-proxy-suffix, test-proxy, p11-kit-proxy\n"
 #define EIGHT_MODULE "module: mock-eight" SHLEXT "\n"
 #define NINE_MODULE "module: mock-nine" SHLEXT "\n"
+#define TEN_MODULE "module: mock-ten" SHLEXT "\n"
 
 static CK_ULONG
 load_modules_and_count_slots (void)
@@ -393,6 +397,43 @@ test_slot_event (void)
 	p11_proxy_module_cleanup ();
 }
 
+static void
+test_reuse_slots (void)
+{
+	CK_FUNCTION_LIST_PTR proxy;
+	CK_SLOT_ID slots[32];
+	CK_ULONG count = 32;
+	CK_RV rv;
+
+	p11_test_file_write (test.directory, "ten.module", TEN_MODULE, strlen (TEN_MODULE));
+
+	rv = C_GetFunctionList (&proxy);
+	assert (rv == CKR_OK);
+
+	assert (p11_proxy_module_check (proxy));
+
+	rv = proxy->C_Initialize (NULL);
+	assert (rv == CKR_OK);
+
+	rv = proxy->C_GetSlotList (CK_FALSE, slots, &count);
+	assert (rv == CKR_OK);
+	assert_num_eq (count, 1);
+
+	count = 32;
+
+	rv = proxy->C_GetSlotList (CK_FALSE, slots, &count);
+	assert (rv == CKR_OK);
+	assert_num_eq (count, 2);
+
+	/* Make sure the assigned slot IDs are different */
+	assert_num_cmp (slots[0], !=, slots[1]);
+
+	rv = proxy->C_Finalize (NULL);
+	assert_num_eq (rv, CKR_OK);
+
+	p11_proxy_module_cleanup ();
+}
+
 static CK_FUNCTION_LIST_PTR
 setup_mock_module (CK_SESSION_HANDLE *session)
 {
@@ -454,7 +495,7 @@ teardown_mock_module (CK_FUNCTION_LIST_PTR module)
 #define MOCK_SKIP_WAIT_TEST
 
 static const CK_INFO mock_info = {
-	{ CRYPTOKI_VERSION_MAJOR, CRYPTOKI_VERSION_MINOR },
+	{ CRYPTOKI_LEGACY_VERSION_MAJOR, CRYPTOKI_LEGACY_VERSION_MINOR },
 	"PKCS#11 Kit                     ",
 	0,
 	"PKCS#11 Kit Proxy Module        ",
@@ -481,8 +522,9 @@ main (int argc,
 	p11_test (test_no_slot, "/proxy/no-slot");
 	p11_test (test_slot_appear, "/proxy/slot-appear");
 	p11_test (test_slot_event, "/proxy/slot-event");
+	p11_test (test_reuse_slots, "/proxy/reuse-slots");
 
-	test_mock_add_tests ("/proxy");
+	test_mock_add_tests ("/proxy", NULL);
 
 	return p11_test_run (argc, argv);
 }
